@@ -3,10 +3,9 @@ from dataclasses import dataclass, field
 from typing import Optional
 
 import cssutils
-from xsdata.formats.converter import Converter, converter
-
-from smpl_util.util import withify
 from smpl_doc.doc import deprecated
+from smpl_util.util import withify
+from xsdata.formats.converter import Converter, converter
 
 # We don't want to see the cssutils warnings, since we have custom properties
 cssutils.log.setLevel(logging.CRITICAL)
@@ -92,7 +91,7 @@ class Styled:
 
     def with_style_properties(self, **kwargs):
         for key, value in kwargs.items():
-            self.put_style_properties(key, value)
+            self.with_style_property(key, value)
         return self
 
     def with_style(self, style):
